Crate bronze_gc

Crate bronze_gc 

Macros

custom_trace
This rule implements the trace method.
simple_empty_finalize_trace
unsafe_empty_trace
This rule implements the trace methods with empty implementations.

Structs

Gc
GcBorrow
GcBorrowMut
GcBox
GcNullableBox
GcNullableRef
GcRef
GcUntypedRoot

Traits

Finalize
The Finalize trait, which needs to be implemented on garbage-collected objects to define finalization logic.
GcTrace

Functions

boxes_len

Foreign Types

Data