Macros
- custom_
trace - This rule implements the trace method.
- simple_
empty_ finalize_ trace - unsafe_
empty_ trace - This rule implements the trace methods with empty implementations.
Structs
Traits
- Finalize
- The Finalize trait, which needs to be implemented on garbage-collected objects to define finalization logic.
- GcTrace